KSM edits to RA8875

Dependents:   Liz_Test_Code

Revision:
73:f22a18707b5e
Parent:
72:ecffe56af969
Child:
76:c981284eb513
--- a/GraphicsDisplay.h	Sat Oct 11 17:24:29 2014 +0000
+++ b/GraphicsDisplay.h	Sun Nov 09 18:52:46 2014 +0000
@@ -207,11 +207,11 @@
     /// @note This method probably has very little value outside of
     ///         the internal methods for reading BMP files.
     ///
     /// @param colorPalette is the handle to the color palette to use.
     /// @param i is the index into the color palette.
     /// @returns the color in color_t format.
     ///
-    color_t RGBQuadToRGB16(RGBQUAD * colorPalette, uint16_t i);
+    color_t RGBQuadToRGB16(RGBQUAD * colorPaletteArray, uint16_t index);
     
     /// This method converts a 16-bit color value into a 24-bit RGB Quad.
     ///
@@ -207,11 +207,11 @@
     ///         the internal methods for reading BMP files.
     ///
-    /// @param colorPalette is the handle to the color palette to use.
-    /// @param i is the index into the color palette.
+    /// @param colorPaletteArray is the handle to the color palette array to use.
+    /// @param index is the index into the color palette.
     /// @returns the color in color_t format.
     ///